@@ -5,12 +5,14 @@ from wsnet.protocol.cmdtypes import CMDType
 from wsnet.protocol import CMD
 
 class WSNConnect(CMD):
-	def __init__(self, token, protocol, ip, port):
+	def __init__(self, token, protocol, ip, port, bind = False, bindtype = 1):
 		self.type = CMDType.CONNECT
 		self.token = token
 		self.protocol = protocol
 		self.ip = ip
 		self.port = port
+		self.bind = bind
+		self.bindtype = bindtype
 
 	@staticmethod
 	def from_bytes(data):
@@ -20,6 +22,7 @@ class WSNConnect(CMD):
 	def from_buffer(buff):
 		token = buff.read(16)
 		protocol = buff.read(3).decode()
+		bind = bool(ord(buff.read(1)))
 		ipver = buff.read(1)
 		if ipver == b'\x04':
 			ip = str(ipaddress.ip_address(buff.read(4)))
@@ -29,7 +32,8 @@ class WSNConnect(CMD):
 			iplen = int.from_bytes(buff.read(4), byteorder='big', signed=False)
 			ip = buff.read(iplen).decode()
 		port = int.from_bytes(buff.read(2), byteorder='big', signed=False)
-		return WSNConnect(token, protocol, ip, port)
+		bindtype = int.from_bytes(buff.read(1), byteorder='big', signed=False)
+		return WSNConnect(token, protocol, ip, port, bind = bind, bindtype = bindtype)
 
 	def to_data(self):
 		t = self.type.value.to_bytes(2, byteorder = 'big', signed = False)
@@ -38,6 +42,7 @@ class WSNConnect(CMD):
 		else:
 			t += self.token
 		t += self.protocol.encode()
+		t += bytes([int(self.bind)])
 		try:
 			ip = ipaddress.ip_address(self.ip)
 		except:
@@ -51,4 +56,6 @@ class WSNConnect(CMD):
 				raise Exception('?')
 		
 		t += self.port.to_bytes(2, byteorder = 'big', signed = False)
+		t += bytes([self.bindtype])
+
 		return t
\ No newline at end of file
